@@ -5,4 +5,8 @@
 let () =
   Pkg.describe "reactiveData" ~builder:`OCamlbuild [
     Pkg.lib "pkg/META";
-    Pkg.lib ~exts:Exts.module_library "src/reactiveData" ]
+    Pkg.lib ~exts:Exts.module_library "src/reactiveData";
+
+    Pkg.doc "README.md";
+    Pkg.doc "CHANGES";
+  ]
